@@ -1,14 +1,12 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "La laste vidita noto ne estas alirebla.",
-    "The notes folder is not accessible: %s" : "La nota dosierujo ne estas alirebla: %s",
+    "Notes" : "Notoj",
     "Error" : "Eraro",
     "New note" : "Nova noto",
-    "Notes" : "Notoj",
     "Distraction-free notes and writing" : "Sendistraj notoj kaj skribado",
-    "Settings" : "Agordoj",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Estas nekonservitaj notoj. Foriro el la paĝo perdos ĉiujn ŝanĝojn!",
+    "Settings" : "Agordoj",
     "Folder to store your notes" : "Dosiero, en kiu konservi viajn notojn",
     "path to notes" : "vojo al notoj",
     "File extension for new notes" : "Dosiersufikso por novaj notoj",
@@ -22,8 +20,8 @@ OC.L10N.register(
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
     "Details" : "Detaloj",
-    "Preview" : "Antaŭvidi",
     "Edit" : "Modifi",
+    "Preview" : "Antaŭvidi",
     "Category" : "Kategorio",
     "Uncategorized" : "Senkategoria",
     "Saving failed!" : "Konservado malsukcesis!",
